@@ -41,7 +41,7 @@ cch <- function(formula, data=sys.parent(), subcoh, id, stratum=NULL, cohort.siz
             warning("stratum levels and names(cohort.size) do not agree")
         subcohort.sizes<-table(stratum)
     } else if(!stratified) {
-        if (!(method =="LinYing"))
+        if (!(method =="LinYing") && robust)
             warning("`robust' ignored for  method (",method,")")
         if (!is.null(stratum))
             warning("'stratum' ignored for method (",method,")")
@@ -334,7 +334,7 @@ vcov.cch<-function(object,...) object$var
     if (x$stratified){
         cat("Exposure-stratified case-cohort analysis,", x$method, "method.\n")
         m<-rbind(subcohort=x$subcohort.size, cohort=x$cohort.size)
-        prmatrix(m,quote=FALSE)
+        print(m,quote=FALSE)
     } else{
         cat("Case-cohort analysis,")
         cat("x$method,", x$method,"\n with subcohort of",
@@ -376,7 +376,7 @@ print.summary.cch <- function(x,digits=3,...){
     if (x$stratified){
         cat("Exposure-stratified case-cohort analysis,", x$method, "method.\n")
         m<-rbind(subcohort=x$subcohort.size, cohort=x$cohort.size)
-        prmatrix(m,quote=FALSE)
+        print(m,quote=FALSE)
     } else{
         cat("Case-cohort analysis,")
         cat("x$method,", x$method,"\n with subcohort of",
@@ -385,8 +385,8 @@ print.summary.cch <- function(x,digits=3,...){
     cat("Call: "); print(x$call)
     cat("\nCoefficients:\n")
     output<-cbind(Coef=x$coefficients[,1],HR=exp(x$coefficients[,1]),
-                  "(95%"=exp(x$coefficients[,1]-2*x$coefficients[,2]),
-                  "CI)"=exp(x$coefficients[,1]+2*x$coefficients[,2]),
+                  "(95%"=exp(x$coefficients[,1]-1.96*x$coefficients[,2]),
+                  "CI)"=exp(x$coefficients[,1]+1.96*x$coefficients[,2]),
                   "p"=x$coefficients[,4]
                   )
     print(round(output,3))
